#[non_exhaustive]pub enum Error {
EmptySegment {
path: String,
},
BadSegment {
path: String,
source: InvalidPart,
},
Canonicalize {
path: PathBuf,
source: Error,
},
InvalidPath {
path: PathBuf,
},
NonUnicode {
path: String,
source: Utf8Error,
},
PrefixMismatch {
path: String,
prefix: String,
},
}Expand description
Error returned by Path::parse
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptySegment
Error when there’s an empty segment between two slashes / in the path
BadSegment
Error when an invalid segment is encountered in the given path
Canonicalize
Error when path cannot be canonicalized
InvalidPath
Error when the path is not a valid URL
NonUnicode
Error when a path contains non-unicode characters
PrefixMismatch
Error when the a path doesn’t start with given prefix